@@ -105,7 +105,11 @@ typedef struct {
   int colormap_size;
   Gif_Colormap *colormap_fixed;
   int colormap_algorithm;
-  int colormap_dither;
+  int dither_type;
+  const uint8_t* dither_data;
+  const char* dither_name;
+  int colormap_gamma_type;
+  double colormap_gamma;
 
   int optimizing;
 
@@ -228,23 +232,25 @@ void	resize_stream(Gif_Stream *, double new_width, double new_height,
  * quantization
  **/
 Gif_Color *histogram(Gif_Stream *, int *);
+#define KC_GAMMA_SRGB			0
+#define KC_GAMMA_NUMERIC		1
+void    kc_set_gamma(int type, double gamma);
 
 #define COLORMAP_DIVERSITY		0
 #define COLORMAP_BLEND_DIVERSITY	1
 #define COLORMAP_MEDIAN_CUT		2
-Gif_Colormap *colormap_blend_diversity(Gif_Color *, int, int, int);
-Gif_Colormap *colormap_flat_diversity(Gif_Color *, int, int, int);
-Gif_Colormap *colormap_median_cut(Gif_Color *, int, int, int);
+Gif_Colormap* colormap_blend_diversity(Gif_Color*, int, Gt_OutputData*);
+Gif_Colormap* colormap_flat_diversity(Gif_Color*, int, Gt_OutputData*);
+Gif_Colormap* colormap_median_cut(Gif_Color*, int, Gt_OutputData*);
 
 typedef struct kd3_tree kd3_tree;
-typedef void (*colormap_image_func)
-     (Gif_Image*, uint8_t*, Gif_Colormap*, kd3_tree*, uint32_t*);
 
-void	colormap_image_posterize
-        (Gif_Image*, uint8_t*, Gif_Colormap*, kd3_tree*, uint32_t*);
-void	colormap_image_floyd_steinberg
-        (Gif_Image*, uint8_t*, Gif_Colormap*, kd3_tree*, uint32_t*);
-void	colormap_stream(Gif_Stream *, Gif_Colormap *, colormap_image_func);
+enum {
+    dither_none = 0, dither_default, dither_floyd_steinberg,
+    dither_ordered, dither_ordered_new
+};
+int     set_dither_type(Gt_OutputData* od, const char* name);
+void	colormap_stream(Gif_Stream*, Gif_Colormap*, Gt_OutputData*);
 
 /*****
  * parsing stuff
